pub struct RequestCreditRegistrationEnrolmentRecheckResult {
pub recheck_started: bool,
pub next_recheck_allowed_at: Option<DateTime<Utc>>,
}Fields
recheck_started: boolFalse when we looked so recently that asking again would tell the student nothing new.
next_recheck_allowed_at: Option<DateTime<Utc>>Trait Implementations
Sourceimpl Clone for RequestCreditRegistrationEnrolmentRecheckResult
impl Clone for RequestCreditRegistrationEnrolmentRecheckResult
Sourcefn clone(&self) -> RequestCreditRegistrationEnrolmentRecheckResult
fn clone(&self) -> RequestCreditRegistrationEnrolmentRecheckResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RequestCreditRegistrationEnrolmentRecheckResult
impl ComposeSchema for RequestCreditRegistrationEnrolmentRecheckResult
Sourceimpl<'de> Deserialize<'de> for RequestCreditRegistrationEnrolmentRecheckResult
impl<'de> Deserialize<'de> for RequestCreditRegistrationEnrolmentRecheckResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RequestCreditRegistrationEnrolmentRecheckResult
impl PartialEq for RequestCreditRegistrationEnrolmentRecheckResult
Sourcefn eq(&self, other: &RequestCreditRegistrationEnrolmentRecheckResult) -> bool
fn eq(&self, other: &RequestCreditRegistrationEnrolmentRecheckResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for RequestCreditRegistrationEnrolmentRecheckResult
impl ToSchema for RequestCreditRegistrationEnrolmentRecheckResult
impl StructuralPartialEq for RequestCreditRegistrationEnrolmentRecheckResult